@@ -9,13 +9,16 @@ names(sym_bonuses) <- c("a", "b", "c")
 sym_bonuses3 <- rnorm(3)
 names(sym_bonuses3) <- as.character(seq_len(length(sym_bonuses3)))
 n_row <- 1000
-d <- data.frame(x1 = rnorm(n_row),
-                x2 = sample(names(sym_bonuses), n_row, replace = TRUE),
-                x3 = sample(names(sym_bonuses3), n_row, replace = TRUE),
-                y = "NoInfo",
-                stringsAsFactors = FALSE)
-d$y[sym_bonuses[d$x2] > pmax(d$x1, sym_bonuses3[d$x3], runif(n_row))] <- "Large1"
-d$y[sym_bonuses3[d$x3] > pmax(sym_bonuses[d$x2], d$x1, runif(n_row))] <- "Large2"
+d <- data.frame(
+  x1 = rnorm(n_row),
+  x2 = sample(names(sym_bonuses), n_row, replace = TRUE),
+  x3 = sample(names(sym_bonuses3), n_row, replace = TRUE),
+  y = "NoInfo",
+  stringsAsFactors = FALSE)
+d$y[sym_bonuses[d$x2] > 
+      pmax(d$x1, sym_bonuses3[d$x3], runif(n_row))] <- "Large1"
+d$y[sym_bonuses3[d$x3] > 
+      pmax(sym_bonuses[d$x2], d$x1, runif(n_row))] <- "Large2"
 
 knitr::kable(head(d))
 
@@ -23,7 +26,6 @@ knitr::kable(head(d))
 # define problem
 vars <- c("x1", "x2", "x3")
 y_name <- "y"
-y_levels <- sort(unique(d[[y_name]]))
 
 # build the multi-class cross frame and treatments
 cfe_m <- mkCrossFrameMExperiment(d, vars, y_name)
@@ -41,11 +43,18 @@ for(vi in vars) {
 str(prepare(cfe_m$treat_m, d))
 
 ## ----varimp--------------------------------------------------------------
-knitr::kable(cfe_m$score_frame)
+knitr::kable(
+  cfe_m$score_frame[, 
+                    c("varName", "rsq", "sig", "outcome_level"), 
+                    drop = FALSE])
 
 ## ----varagg--------------------------------------------------------------
 
-tapply(cfe_m$score_frame$rsq, cfe_m$score_frame$origName, max)
+tapply(cfe_m$score_frame$rsq, 
+       cfe_m$score_frame$origName, 
+       max)
 
-tapply(cfe_m$score_frame$sig, cfe_m$score_frame$origName, min)
+tapply(cfe_m$score_frame$sig, 
+       cfe_m$score_frame$origName, 
+       min)
 
